define({ "api": [
  {
    "name": "Add",
    "group": "Address",
    "type": "post",
    "url": "/api/address/add",
    "title": "Add email address",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "address",
            "description": "<p>E-mail address</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&address=test@example.com\" https://mailcleaner/api/address/add",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>address test@example.com in domain example.com added</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n   <message>Cannot add address: Address already exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/AddressAPI.php",
    "groupTitle": "Address"
  },
  {
    "name": "Delete",
    "group": "Address",
    "type": "post",
    "url": "/api/address/delete/address",
    "title": "Delete email address",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "address",
            "description": ""
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&address=test@example.com\" https://mailcleaner/api/address/delete",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>address test@example.com in domain example.com deleted</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n    <message>Cannot delete address: Address does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/AddressAPI.php",
    "groupTitle": "Address"
  },
  {
    "name": "Edit",
    "group": "Address",
    "type": "post",
    "url": "/api/address/edit/address",
    "title": "Edit email address",
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&address=test@example.com&summary_type=text&summary_frequency=daily\" \\\n > https://mailcleaner/api/address/edit",
        "type": "curl"
      }
    ],
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "emailAddress",
            "description": "<p>E-mail address</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "domain",
            "description": "<p>Domain (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "spam_tag",
            "description": "<p>Spam Tag (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "summary_type",
            "description": "<p>Summary type (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "summary_frequency",
            "description": "<p>Summary frequency (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "send_reports_to",
            "description": "<p>Send reports to (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "quarantine_bounce",
            "description": "<p>Quanrantine bounce (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "send_to_archiver",
            "description": "<p>Send to archiver (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "send_copy_to",
            "description": "<p>Send copy to (optional)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "user",
            "description": "<p>User (optional)</p> "
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "200",
            "description": "<p>Success XML string example</p> "
          }
        ]
      },
      "examples": [
        {
          "title": "XML string response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>address test@example.com in domain example.com edited</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML string example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n    <message>Cannot edit address: Address does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/AddressAPI.php",
    "groupTitle": "Address"
  },
  {
    "name": "Exists",
    "group": "Address",
    "type": "get",
    "url": "/api/address/exists/address/:address",
    "title": "Test email address",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "address",
            "description": "<p>E-mail address</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage:",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/address/exists/test@example.com",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n     <message>address test@example.com</message>\n     <data>\n         <address>test@example.com</address>\n         <domain>example.com</domain>\n         <action_on_spam>quarantine</action_on_spam>\n         <spam_tag>{Spam?}</spam_tag>\n         <summary_type>html</summary_type>\n         <summary_frequency>weekly</summary_frequency><send_reports_to/>\n         <quarantine_bounce>0</quarantine_bounce>\n         <send_to_archiver>0</send_to_archiver>\n         <send_copy_to/>\n     </data>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n    <message>Address does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/AddressAPI.php",
    "groupTitle": "Address"
  },
  {
    "name": "List",
    "group": "Address",
    "type": "get",
    "url": "/api/address/list/address/search/domain/:domain",
    "title": "List email addresses",
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" \\ \n> https://mailcleaner/api/address/list/address/search/domain/example.com",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Addresses</message>\n    <data>\n         <element>test1@example.com</element>\n         <element>test2@example.com</element>\n         <element>test3@exmaple.com</element>\n    </data>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/AddressAPI.php",
    "groupTitle": "Address"
  },
  {
    "type": "get",
    "url": "/api/address/show/address/:addess",
    "title": "Get email address",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "address",
            "description": "<p>E-Mail address</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/address/show/address/test@example.com",
        "type": "curl"
      }
    ],
    "name": "Show",
    "group": "Address",
    "success": {
      "examples": [
        {
          "title": "200 Success XML string respsonse example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>address test@example.com</message>\n    <data>\n        <address>test@example.com</address>\n        <domain>example.com</domain>\n        <action_on_spam>quarantine</action_on_spam>\n        <spam_tag>{Spam?}</spam_tag><summary_type>html</summary_type>\n        <summary_frequency>weekly</summary_frequency><send_reports_to/>\n        <quarantine_bounce>0</quarantine_bounce>\n        <send_to_archiver>0</send_to_archiver>\n        <send_copy_to/>\n    </data>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML string response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n    <message>Cannot show address: Address does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/AddressAPI.php",
    "groupTitle": "Address"
  },
  {
    "name": "Add",
    "group": "Domain",
    "type": "post",
    "url": "/api/domain/add",
    "title": "Add domain",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "name",
            "description": "<p>Domain name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&name=example.com\" https://mailcleaner/api/domain/add",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Domain example.com successfully added</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\"><message>domain already exists</message></response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/DomainAPI.php",
    "groupTitle": "Domain"
  },
  {
    "name": "Edit",
    "group": "Domain",
    "type": "post",
    "url": "/api/domain/edit",
    "title": "Edit domain",
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&name=example.com&allow_smtp_auth=1\" \\\n> https://mailcleaner/api/domain/edit",
        "type": "curl"
      }
    ],
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "aliases",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "systemsender",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "falseneg_to",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "falsepos_to",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "supportname",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "supportemail",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "destination_mode",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "destination_usemx",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "destination",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "callout_connector",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "language",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "summary_frequency",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "summary_type",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "delivery_type",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "spam_tag",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "content_tag",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "file_tag",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "virus_tag",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "auth_connector",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "prevent_spoof",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "require_incoming_tls",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "spamwall",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "contentwall",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "viruswall",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "greylist",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "web_template",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "summary_template",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "whitelists",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "warnlists",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "notice_wwlists",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "allow_smtp_auth",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "require_outgoing_tls",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "batv_enable",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "batv_secret",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "dkim_domain",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "dkim_selector",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "dkim_private_key",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "send_to_archiver",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "send_copy_to",
            "description": ""
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "200 Success XML string response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Domain example.com successfully edited</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/DomainAPI.php",
    "groupTitle": "Domain"
  },
  {
    "name": "List",
    "group": "Domain",
    "type": "get",
    "url": "/api/user/list/domain",
    "title": "List domains",
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/domain/list",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Domains</message>\n    <data>\n         <element>example.com</element>\n    </data>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/DomainAPI.php",
    "groupTitle": "Domain"
  },
  {
    "name": "Remove",
    "group": "Domain",
    "type": "post",
    "url": "/api/domain/remove",
    "title": "Delete domain",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "name",
            "description": "<p>Domain name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&name=example.com\" https://mailcleaner/api/domain/delete",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Domain example.com removed</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Domain example.com removed</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/DomainAPI.php",
    "groupTitle": "Domain"
  },
  {
    "type": "get",
    "url": "/api/domain/show/name/:name",
    "title": "Get domain",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "name",
            "description": "<p>Domain name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/domain/show/name/example.com",
        "type": "curl"
      }
    ],
    "name": "Show",
    "group": "Domain",
    "success": {
      "examples": [
        {
          "title": "200 Success XML string response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Domain example.com settings</message>\n    <data>\n        <aliases></aliases>\n        <systemsender></systemsender>\n        <falseneg_to></falseneg_to>\n        <falsepos_to></falsepos_to>\n        <supportname></supportname>\n        <supportemail></supportemail>\n        <destination_mode>loadbalancing</destination_mode>\n        <destination_usemx>0</destination_usemx>\n        <destination>smtp.example.com:25</destination>\n        <callout_connector>none</callout_connector>\n        <language>en</language>\n        <summary_frequency>weekly</summary_frequency>\n        <summary_type>html</summary_type>\n        <delivery_type>quarantine</delivery_type>\n        <spam_tag>{Spam?}</spam_tag>\n        <content_tag>{Content?}</content_tag>\n        <file_tag>{Virus?}</file_tag>\n        <virus_tag>{Virus?}</virus_tag>\n        <auth_connector>local</auth_connector>\n        <prevent_spoof>0</prevent_spoof>\n        <require_incoming_tls>0</require_incoming_tls>\n        <spamwall>1</spamwall><contentwall>1</contentwall>\n        <viruswall>1</viruswall>\n        <greylist>0</greylist>\n        <web_template>default</web_template>\n        <summary_template>default</summary_template>\n        <whitelists>0</whitelists>\n        <warnlists>0</warnlists>\n        <notice_wwlists>0</notice_wwlists>\n        <allow_smtp_auth>0</allow_smtp_auth>\n        <require_outgoing_tls>0</require_outgoing_tls>\n        <batv_enable>0</batv_enable><batv_secret>\n        </batv_secret><dkim_domain></dkim_domain>\n        <dkim_selector></dkim_selector>\n        <dkim_private_key></dkim_private_key>\n        <send_to_archiver>0</send_to_archiver>\n        <send_copy_to></send_copy_to>\n</data>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML string response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n    <message>Domain does not exists or you don't have sufficient permissions</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/DomainAPI.php",
    "groupTitle": "Domain"
  },
  {
    "name": "Show",
    "group": "Quarantine",
    "type": "get",
    "url": "/api/domain/quarantine/getspam/id/:id",
    "title": "Get spam",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "id",
            "description": "<p>Exim ID (Mailcleaner mail ID)</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "recipient",
            "description": "<p>Recipient</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/address/show/address/test@example.com",
        "type": "curl"
      }
    ],
    "error": {
      "examples": [
        {
          "title": "200 Success XML string response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>Quarantined message 1ZF2Dk-0004XJ-7I data</message>\n    <data>\n        <exim_id>1ZF2Dk-0004XJ-7I</exim_id>\n        <to_user>nonexist</to_user>\n        <to_domain>example.com</to_domain>\n        <date_in>2015-07-14</date_in>\n        <time_in>17:34:15</time_in>\n        <sender>test@microsoft.com</sender>\n        <M_subject> test Tue, 14 Jul 2015 17:36:44 +0200</M_subject>\n        <forced>0</forced><M_score>5.800</M_score>\n        <M_rbls>0</M_rbls>\n        <M_prefilter>SpamC</M_prefilter>\n        <M_globalscore>1</M_globalscore>\n        <store_slave>1</store_slave>\n        <headers>Received: from smtp.example.com ([192.168.1.1] helo=smtp.example.com)\n              by example.com stage1 with esmtp \n              (Exim MailCleaner) \n              id 1AAABa-0005XX-1y \n              for &lt;recipient@example.com&gt; \n              from &lt;sender@example.com&gt;; Tue, 01 Jul 2015 00:00:00 +0200\n              X-MailCleaner-SPF: fail\n              Date: Tue, 14 Jul 2015 17:36:44 +0200\n              To: recipent@example.com\n              From: sender@example.com\n              Subject: test Tue, 01 Jul 2015 00:00:00 +0200\n              X-Mailer: swaks v20130209.0 jetmore.org/john/code/swaks/\n              Authentication-Results: localhost; dmarc=none header.from=microsoft.com\n              X-Spamc: is spam (10.0/5.0)\n              X-MailCleaner-Information: Please contact  for more information\n              X-MailCleaner-ID: 1AAABa-0005XX-2y \n              X-MailCleaner: Found to be clean\n             X-MailCleaner-SpamCheck: spam, Spamc (score=10.0, required=5.0, BAYES_50 10.0)\n              X-Auto-Response-Suppress: DR, NDR, RN, NRN, OOF, AutoReply\n        </headers>\n    </data>\n </response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/QuarantineAPI.php",
    "groupTitle": "Quarantine"
  },
  {
    "name": "Add",
    "group": "User",
    "type": "post",
    "url": "/api/user/add",
    "title": "Add user",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "user",
            "description": "<p>Username</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&user=test&domain=example.com\" https://mailcleaner/api/user/add",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n <response code=\"200\" name=\"success\">\n      <message>user test@example.com in domain exemple.com added</message>\n </response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n      <message>user test@example.com in domain example.com added</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/UserAPI.php",
    "groupTitle": "User"
  },
  {
    "name": "Delete",
    "group": "User",
    "type": "post",
    "url": "/api/address/delete",
    "title": "Delete user",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "user",
            "description": "<p>Username</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "domain",
            "description": "<p>Domaine name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&user=test&domain=example.com\" https://mailcleaner/api/address/delete",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>user test@example.com in domain example.com deleted</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML response",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n     <message>Cannot delete user: User does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/UserAPI.php",
    "groupTitle": "User"
  },
  {
    "name": "Edit",
    "group": "User",
    "type": "post",
    "url": "/api/user/edit",
    "title": "Edit user",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "username",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "domain",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "gui_default_address",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "gui_displayed_spams",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "gui_displayed_days",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "gui_mask_forced",
            "description": ""
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "addresses",
            "description": ""
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example&gui_displayed_days=3\" \\\n> https://mailcleaner/api/user/edit/user/test/domain/example.com",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n     <message>user test@example.com in domain example.com edited</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/UserAPI.php",
    "groupTitle": "User"
  },
  {
    "name": "Exists",
    "group": "User",
    "type": "get",
    "url": "/api/user/exists/user/:user/domain/:domain",
    "title": "",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "user",
            "description": "<p>Username</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "domain",
            "description": "<p>Domain name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage:",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/user/exists/user/test/domain/example.com",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n    <message>user test@example.com in domain example.com exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML String response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n     <message>User does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/UserAPI.php",
    "groupTitle": "User"
  },
  {
    "name": "List",
    "group": "User",
    "type": "get",
    "url": "/api/user/list/user/search/domain/:domain",
    "title": "List users",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "domain",
            "description": "<p>Domain name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/user/list/user/search/domain/example.com",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML String example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n     <message>Users</message>\n     <data>\n          <element>test1@example.com</element>\n          <element>test2@example.com</element>\n          <element>test3@example.com</element>\n     </data>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/UserAPI.php",
    "groupTitle": "User"
  },
  {
    "name": "Show",
    "group": "User",
    "type": "get",
    "url": "/api/user/show/user/:user/domain/:domain",
    "title": "Get user",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "user",
            "description": "<p>Username</p> "
          },
          {
            "group": "Parameter",
            "type": "<p>string</p> ",
            "optional": false,
            "field": "domain",
            "description": "<p>Domain name</p> "
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Example usage",
        "content": "curl -k --data \"username=example&password=example\" https://mailcleaner/api/user/show/user/test/domain/example.com",
        "type": "curl"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "200 Success XML string respsonse example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"200\" name=\"success\">\n     <message>user test@example.com</message>\n     <data>\n         <username>test@example.com</username>\n         <domain>example.com</domain>\n         <gui_default_address></gui_default_address>\n         <gui_displayed_spams>20</gui_displayed_spams>\n         <gui_displayed_days>7</gui_displayed_days>\n         <gui_mask_forced>0</gui_mask_forced>\n         <addresses><element>test@example.com</element></addresses>\n     </data>\n</response>",
          "type": "json"
        }
      ]
    },
    "error": {
      "examples": [
        {
          "title": "500 Error XML string response example",
          "content": "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<response code=\"500\" name=\"server-error\">\n     <message>Cannot show user: User does not exists</message>\n</response>",
          "type": "json"
        }
      ]
    },
    "version": "1.0.0",
    "filename": "./models/UserAPI.php",
    "groupTitle": "User"
  },
  {
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "optional": false,
            "field": "500",
            "description": "<p>Address does not exist</p> "
          }
        ]
      }
    },
    "type": "",
    "url": "",
    "version": "0.0.0",
    "filename": "./models/AddressAPI.php",
    "group": "_var_www_html_mcdev_mailcleaner_www_api_application_api_models_AddressAPI_php",
    "groupTitle": "_var_www_html_mcdev_mailcleaner_www_api_application_api_models_AddressAPI_php",
    "name": ""
  }
] });